==> nextcloud-22.2.0.tgz: nextcloud/apps/comments/l10n/hu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Hozzászólások",
    "You commented" : "Hozzászólt",
    "%1$s commented" : "%1$s hozzászólt",
    "{author} commented" : "{author} hozzászólt",
    "You commented on %1$s" : "Hozzászólt ehhez: %1$s",
    "You commented on {file}" : "Hozzászólt ehhez: {file}",
    "%1$s commented on %2$s" : "%1$s hozzászólt ehhez: %2$s",
    "{author} commented on {file}" : "{author} hozzászólt ehhez: {file}",
    "<strong>Comments</strong> for files" : "<strong>Hozzászólások</strong> fájlokhoz",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Megemlítették ennél: „{file}”, egy már törölt felhasználó hozzászólásában",
    "{user} mentioned you in a comment on “{file}”" : "{user} megemlítette egy hozzászólásban ennél: „{file}”",
    "Files app plugin to add comments to files" : "A Fájlok alkalmazás bővítménye, amellyel megjegyzések adhatóak a fájlokhoz",
    "Edit comment" : "Hozzászólás szerkesztése",
    "Delete comment" : "Hozzászólás törlése",
    "Cancel edit" : "Változások elvetése",
    "Post comment" : "Hozzászólás közzététele",
    "No comments yet, start the conversation!" : "Még nincsenek hozzászólások, kezdje el a beszélgetést!",
    "No more messages" : "Nincs több üzenet",
    "Retry" : "Újra",
    "Unable to load the comments list" : "A hozzászólások betöltése sikertelen",
    "_%n unread comment_::_%n unread comments_" : ["%n olvasatlan hozzászólás","%n olvasatlan hozzászólás"],
    "_1 new comment_::_{unread} new comments_" : ["1 új hozzászólás","{unread} új hozzászólás"],
    "Comment" : "Hozzászólás",
    "An error occurred while trying to edit the comment" : "Hiba történt a megjegyzés szerkesztése közben",
    "Comment deleted" : "Hozzászólás törölve",
    "An error occurred while trying to delete the comment" : "Hiba történt a megjegyzés törlése közben",
    "An error occurred while trying to create the comment" : "Hiba történt a megjegyzés létrehozása közben",
    "New comment …" : "Új hozzászólás…",
    "Post" : "Küldés",
    "Cancel" : "Mégse",
    "[Deleted user]" : "[Törölt felhasználó]",
    "More comments …" : "Több hozzászólás…",
    "Save" : "Mentés",
    "Allowed characters {count} of {max}" : "Engedélyezett karakterek: {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "Hiba a(z) {id} azonosítójú hozzászólás betöltésekor",
    "Error occurred while updating comment with id {id}" : "Hiba a(z) {id} azonosítójú hozzászólás frissítésekor",
    "Error occurred while posting comment" : "Hiba történt a hozzászólás küldése közben"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.4.tgz: nextcloud/apps/comments/l10n/hu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Hozzászólások",
    "You commented" : "Hozzászólt",
    "%1$s commented" : "%1$s hozzászólt",
    "{author} commented" : "{author} hozzászólt",
    "You commented on %1$s" : "Hozzászólt ehhez: %1$s",
    "You commented on {file}" : "Hozzászólt ehhez: {file}",
    "%1$s commented on %2$s" : "%1$s hozzászólt ehhez: %2$s",
    "{author} commented on {file}" : "{author} hozzászólt ehhez: {file}",
    "<strong>Comments</strong> for files" : "<strong>Hozzászólások</strong> fájlokhoz",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Megemlítették ennél: „{file}”, egy már törölt felhasználó hozzászólásában",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} megemlítette egy hozzászólásban ennél: „{file}”",
    "Files app plugin to add comments to files" : "A Fájlok alkalmazás bővítménye, amellyel megjegyzések adhatóak a fájlokhoz",
    "Edit comment" : "Hozzászólás szerkesztése",
    "Delete comment" : "Hozzászólás törlése",
    "Cancel edit" : "Változások elvetése",
    "Post comment" : "Hozzászólás közzététele",
    "No comments yet, start the conversation!" : "Még nincsenek hozzászólások, kezdje el a beszélgetést!",
    "No more messages" : "Nincs több üzenet",
    "Retry" : "Újra",
    "Unable to load the comments list" : "A hozzászólások betöltése sikertelen",
    "_%n unread comment_::_%n unread comments_" : ["%n olvasatlan hozzászólás","%n olvasatlan hozzászólás"],
    "_1 new comment_::_{unread} new comments_" : ["1 új hozzászólás","{unread} új hozzászólás"],
    "Comment" : "Hozzászólás",
    "An error occurred while trying to edit the comment" : "Hiba történt a megjegyzés szerkesztése közben",
    "Comment deleted" : "Hozzászólás törölve",
    "An error occurred while trying to delete the comment" : "Hiba történt a megjegyzés törlése közben",
    "An error occurred while trying to create the comment" : "Hiba történt a megjegyzés létrehozása közben",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Megemlítették ennél: „{file}”, egy már törölt felhasználó hozzászólásában",
    "{user} mentioned you in a comment on “{file}”" : "{user} megemlítette egy hozzászólásban ennél: „{file}”",
    "New comment …" : "Új hozzászólás…",
    "Post" : "Küldés",
    "Cancel" : "Mégse",
    "[Deleted user]" : "[Törölt felhasználó]",
    "More comments …" : "Több hozzászólás…",
    "Save" : "Mentés",
    "Allowed characters {count} of {max}" : "Engedélyezett karakterek: {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "Hiba a(z) {id} azonosítójú hozzászólás betöltésekor",
    "Error occurred while updating comment with id {id}" : "Hiba a(z) {id} azonosítójú hozzászólás frissítésekor",
    "Error occurred while posting comment" : "Hiba történt a hozzászólás küldése közben"
},
"nplurals=2; plural=(n != 1);");
